==> cjsb-0.0.4.tgz: package/lib/cli.js <==
#!/usr/bin/env node
"use strict";

var _yargsParser = _interopRequireDefault(require("yargs-parser"));

var _child_process = require("child_process");

var _glob = _interopRequireDefault(require("glob"));

var babel = _interopRequireWildcard(require("@babel/core"));

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _path = _interopRequireDefault(require("path"));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const argv = (0, _yargsParser.default)(process.argv.slice(2), {
  alias: {
    declaration: ["d"]
  }
});
const {
  cwd = process.cwd(),
  source = "src",
  outDir = "lib",
  nodeVersion = 12,
  declaration
} = argv;

const filesDir = _path.default.join(cwd, source);

const toJsFile = filePath => {
  const {
    dir,
    name
  } = _path.default.parse(filePath);

  return _path.default.format({
    dir,
    name,
    ext: ".js"
  });
};

const toRelative = filePath => _path.default.relative(filesDir, filePath);

const files = _glob.default.sync("**/*", {
  cwd: filesDir,
  nodir: true,
  absolute: true
}).filter(file => file.endsWith(".js") || file.endsWith(".ts") && !file.endsWith(".d.ts"));

_fsExtra.default.removeSync(outDir);

files.forEach(filePath => {
  const {
    code
  } = babel.transformFileSync(filePath, {
    babelrc: false,
    configFile: false,
    presets: [["@babel/preset-env", {
      targets: {
        node: nodeVersion
      }
    }], "@babel/preset-typescript"]
  });

  const outputPath = _path.default.join(outDir, toJsFile(toRelative(filePath)));

  _fsExtra.default.outputFileSync(outputPath, code, "utf-8");
});

if (declaration) {
  const sourceTscConfig = _path.default.join(cwd, "tsconfig.json");

  const tsConfigPath = typeof declaration === "boolean" ? sourceTscConfig : declaration;
  let originContent;

  if (_fsExtra.default.existsSync(sourceTscConfig)) {
    originContent = _fsExtra.default.readFileSync(sourceTscConfig, "utf-8");
  } else if (typeof declaration === "boolean") {
    _fsExtra.default.writeFileSync(sourceTscConfig, "{}", "utf-8");
  }

  const options = require(tsConfigPath);

  options.include = [source];
  options.compilerOptions = Object.assign({}, options.compilerOptions, {
    noEmit: false,
    declaration: true,
    emitDeclarationOnly: true,
    declarationDir: outDir
  });

  try {
    _fsExtra.default.writeFileSync(tsConfigPath, JSON.stringify(options));

    (0, _child_process.execSync)("tsc", {
      stdio: "inherit"
    });
  } finally {
    _fsExtra.default.removeSync(tsConfigPath);

    if (originContent) {
      _fsExtra.default.writeFileSync(sourceTscConfig, originContent, "utf-8");
    }
  }
}

==> cjsb-0.0.6.tgz: package/lib/cli.js <==
#!/usr/bin/env node
"use strict";

var _yargsParser = _interopRequireDefault(require("yargs-parser"));

var _child_process = require("child_process");

var _glob = _interopRequireDefault(require("glob"));

var babel = _interopRequireWildcard(require("@babel/core"));

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _path = _interopRequireDefault(require("path"));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const argv = (0, _yargsParser.default)(process.argv.slice(2), {
  alias: {
    declaration: ["d"]
  }
});
const {
  cwd = process.cwd(),
  source = "src",
  outDir = "lib",
  nodeVersion = 12,
  declaration
} = argv;

const filesDir = _path.default.join(cwd, source);

const toJsFile = filePath => {
  const {
    dir,
    name
  } = _path.default.parse(filePath);

  return _path.default.format({
    dir,
    name,
    ext: ".js"
  });
};

const toRelative = filePath => _path.default.relative(filesDir, filePath);

const files = _glob.default.sync("**/*", {
  cwd: filesDir,
  nodir: true,
  absolute: true
}).filter(file => file.endsWith(".js") || file.endsWith(".ts") && !file.endsWith(".d.ts"));

_fsExtra.default.removeSync(outDir);

files.forEach(filePath => {
  const {
    code
  } = babel.transformFileSync(filePath, {
    babelrc: false,
    configFile: false,
    presets: [["@babel/preset-env", {
      targets: {
        node: nodeVersion
      }
    }], "@babel/preset-typescript"]
  });

  const outputPath = _path.default.join(outDir, toJsFile(toRelative(filePath)));

  _fsExtra.default.outputFileSync(outputPath, code, "utf-8");
});

if (declaration) {
  const sourceTscConfig = _path.default.join(cwd, "tsconfig.json");

  let originContent;

  if (_fsExtra.default.existsSync(sourceTscConfig)) {
    originContent = _fsExtra.default.readFileSync(sourceTscConfig, "utf-8");
  } else {
    _fsExtra.default.writeFileSync(sourceTscConfig, "{}", "utf-8");
  }

  const options = require(sourceTscConfig);

  options.include = [source];
  options.compilerOptions = Object.assign({}, options.compilerOptions, {
    target: "ESNext",
    noEmit: false,
    declaration: true,
    emitDeclarationOnly: true,
    declarationDir: outDir,
    esModuleInterop: true,
    moduleResolution: "node"
  });

  try {
    _fsExtra.default.writeFileSync(sourceTscConfig, JSON.stringify(options));

    (0, _child_process.execSync)("tsc", {
      stdio: "inherit"
    });
  } finally {
    _fsExtra.default.removeSync(sourceTscConfig);

    if (originContent) {
      _fsExtra.default.writeFileSync(sourceTscConfig, originContent, "utf-8");
    }
  }
}
